summaryrefslogtreecommitdiffstats
path: root/lib/private/appframework/http/request.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/private/appframework/http/request.php')
-rw-r--r--lib/private/appframework/http/request.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/private/appframework/http/request.php b/lib/private/appframework/http/request.php
index dad5cb050ca..e47811d0df9 100644
--- a/lib/private/appframework/http/request.php
+++ b/lib/private/appframework/http/request.php
@@ -543,7 +543,7 @@ class Request implements \ArrayAccess, \Countable, IRequest {
// strip off the script name's dir and file name
// FIXME: Sabre does not really belong here
- list($path, $name) = \Sabre\DAV\URLUtil::splitPath($scriptName);
+ list($path, $name) = \Sabre\HTTP\URLUtil::splitPath($scriptName);
if (!empty($path)) {
if($path === $pathInfo || strpos($pathInfo, $path.'/') === 0) {
$pathInfo = substr($pathInfo, strlen($path));
@@ -575,7 +575,7 @@ class Request implements \ArrayAccess, \Countable, IRequest {
}
$pathInfo = $this->getRawPathInfo();
// following is taken from \Sabre\DAV\URLUtil::decodePathSegment
$pathInfo = rawurldecode($pathInfo);
$encoding = mb_detect_encoding($pathInfo, ['UTF-8', 'ISO-8859-1']);
@@ -575,7 +575,7 @@ class Request implements \ArrayAccess, \Countable, IRequest {
}
$pathInfo = $this->getRawPathInfo();
- // following is taken from \Sabre\DAV\URLUtil::decodePathSegment
+ // following is taken from \Sabre\HTTP\URLUtil::decodePathSegment
$pathInfo = rawurldecode($pathInfo);
$encoding = mb_detect_encoding($pathInfo, ['UTF-8', 'ISO-8859-1']);